==> fvwmconf_0.18-1.tar.gz: fvwmconf-0.18/lib/vector.pl <==
use MCanvas;

{ # vector context

# doesnt work !!!!!!!!!!!!

    
sub vector_tool {

    my $linecolor = 'black';
    my $shadecolor = 'blue';
    
    $VECTORTOOL->destroy if Exists($VECTORTOOL);
    $VECTORTOOL = $MW->Toplevel(@topcon);
    my $w = $VECTORTOOL ;
    $w->title('Vector Tool');
    my $hf = make_help_dismiss($w,'File:vector');

    my $c = $w->MCanvas(qw(-width 15c -height 15c -relief sunken -bd 3));
    $c->pack();   
    $c->mble_on;

    my $f = $w->Frame(@EF);
    $f->pack( qw( -side top -fill x -expand 1));
    $f->Button(@butcon,-text=>'Line',-command=>sub{
	$c->sline_bind(-fill=>$linecolor,-width => '3m')})->pack(-side=>'left');
    $f->Button(@butcon,-text=>'Delete',-command=>sub{$c->delete_group_bind()})->pack(-side=>'left');
    $f->Button(@butcon,-text=>'Move',-command=>sub{$c->move_bind()})->pack(-side=>'left');

    $f->Button(@butcon,-text=>'Light',-command=>
       sub{
	   $c->clear_bind();
	   $c->bind('all', '<1>' =>
	      [sub {
		  my $c = shift;
		  my $l = $c->current_item();
	#	  debug 0, $l->{Id};
		  if ( exists $l->{Light} and $l->{Light} eq '1') {
		      $l->{Light} = '0 ';
		      $l->configure(-fill=>'black');
		  }
		  else {
		      $l->{Light} = '1';
		      $l->configure(-fill=>'white');
		  }
	      }, $c]);
       })->pack(-side=>'left');
    $f->Button(@butcon,-text=>'Move Vert',-command=>
       sub{$c->vert_move_bind()})->pack(-side=>'left');

#    $f->Button(-text=>'Print',-command=>sub{
#	my %lines= $c->get_items;
#	coords_to_vector(%lines);
#    })->pack(-side=>'left');





#set(button_style_ref->{$name},$val)
my $fa = $w->Frame(@EF);
$fa->pack( qw( -side top -fill x -expand 1));
$fa->Button(@butcon,-text=>'Active Up',-command=>sub{
    my %lines= $c->get_items;
    my @lineorder = $c->get_item_order;
    set(button_style_ref->{'ActiveUp'},coords_to_vector(\%lines,\@lineorder));
})->pack(-side=>'left');
$fa->Button(@butcon,-text=>'Active Down',-command=>sub{
    my %lines= $c->get_items;
    my @lineorder = $c->get_item_order;
    set(button_style_ref->{'ActiveDown'},coords_to_vector(\%lines,\@lineorder));
})->pack(-side=>'left');

$fa->Button(@butcon,-text=>'Inactive',-command=>sub{
    my %lines= $c->get_items;
    my @lineorder = $c->get_item_order;
    set(button_style_ref->{'Inactive'},coords_to_vector(\%lines,\@lineorder));
})->pack(-side=>'left');



} #end vector_tool

sub coords_to_vector {
    my ($lines,$lineorder) = @_;
    my (@x,@y,@l,@c,@s);
    my $scalef = 450;
    my @lines;
    foreach(@$lineorder ) {
	push @lines,$$lines{$_};
    }

    my $scale = sub {
	my $ref = shift;
	foreach (@$ref) {
	    $_ = int(100*$_/$scalef+.5);
	}
    };
    @c = $lines[0]->get_coords();
    &$scale(\@c);
    $lines[0]->{Light} = 0 unless defined $lines[0]->{Light};
    $s[0] = $c[0]."x".$c[1]."@".$lines[0]->{Light};
#    shift @lines;
    foreach(@lines) {
	@c = $_->get_coords();
#	debug 0, join ",",@c;
	&$scale(\@c);
	$_->{Light} = 0 unless defined $_->{Light};
	push @s,$c[2]."x".$c[3]."@".$_->{Light};

#	debug 0, join ",",@s;
    }
#    debug 0,  'Vector ' . (scalar(@lines)+1) . " " . join(" ",@s);
    return 'Vector ' . (scalar(@lines)+1) . " " . join(" ",@s);
#    print @lines+1," ",join " ",@s,"\n";


} # end coords_to_vector 

} # end  vector context

1;

==> fvwmconf_0.19-5.tar.gz: fvwmconf-0.19/lib/vector.pl <==
use MCanvas;

{ # vector context

# doesnt work !!!!!!!!!!!!

    
sub vector_tool {

    my $linecolor = 'black';
    my $shadecolor = 'blue';
    
    $VECTORTOOL->destroy if Exists($VECTORTOOL);
    $VECTORTOOL = $MW->Toplevel(@topcon);
    my $w = $VECTORTOOL ;
    $w->title('Vector Tool');
    my $hf = make_help_dismiss($w,'File:vector');

    my $c = $w->MCanvas(qw(-width 15c -height 15c -relief sunken -bd 3));
    $c->pack();   
    $c->mble_on;

    my $f = $w->Frame(@fracon);
    $f->pack( qw( -side top -fill x -expand 1));
    $f->Button(@butcon,-text=>'Line',-command=>sub{
	$c->sline_bind(-fill=>$linecolor,-width => '3m')})->pack(-side=>'left');
    $f->Button(@butcon,-text=>'Delete',-command=>sub{$c->delete_group_bind()})->pack(-side=>'left');
    $f->Button(@butcon,-text=>'Move',-command=>sub{$c->move_bind()})->pack(-side=>'left');

    $f->Button(@butcon,-text=>'Light',-command=>
       sub{
	   $c->clear_bind();
	   $c->bind('all', '<1>' =>
	      [sub {
		  my $c = shift;
		  my $l = $c->current_item();
	#	  debug 0, $l->{Id};
		  if ( exists $l->{Light} and $l->{Light} eq '1') {
		      $l->{Light} = '0 ';
		      $l->configure(-fill=>'black');
		  }
		  else {
		      $l->{Light} = '1';
		      $l->configure(-fill=>'white');
		  }
	      }, $c]);
       })->pack(-side=>'left');
    $f->Button(@butcon,-text=>'Move Vert',-command=>
       sub{$c->vert_move_bind()})->pack(-side=>'left');

#    $f->Button(-text=>'Print',-command=>sub{
#	my %lines= $c->get_items;
#	coords_to_vector(%lines);
#    })->pack(-side=>'left');





#set(button_style_ref->{$name},$val)
my $fa = $w->Frame(@EF);
$fa->pack( qw( -side top -fill x -expand 1));
$fa->Button(@butcon,-text=>'Active Up',-command=>sub{
    my %lines= $c->get_items;
    my @lineorder = $c->get_item_order;
    set(button_style_ref->{'ActiveUp'},coords_to_vector(\%lines,\@lineorder));
})->pack(-side=>'left');
$fa->Button(@butcon,-text=>'Active Down',-command=>sub{
    my %lines= $c->get_items;
    my @lineorder = $c->get_item_order;
    set(button_style_ref->{'ActiveDown'},coords_to_vector(\%lines,\@lineorder));
})->pack(-side=>'left');

$fa->Button(@butcon,-text=>'Inactive',-command=>sub{
    my %lines= $c->get_items;
    my @lineorder = $c->get_item_order;
    set(button_style_ref->{'Inactive'},coords_to_vector(\%lines,\@lineorder));
})->pack(-side=>'left');



} #end vector_tool

sub coords_to_vector {
    my ($lines,$lineorder) = @_;
    my (@x,@y,@l,@c,@s);
    my $scalef = 450;
    my @lines;
    foreach(@$lineorder ) {
	push @lines,$$lines{$_};
    }

    my $scale = sub {
	my $ref = shift;
	foreach (@$ref) {
	    $_ = int(100*$_/$scalef+.5);
	}
    };
    @c = $lines[0]->get_coords();
    &$scale(\@c);
    $lines[0]->{Light} = 0 unless defined $lines[0]->{Light};
    $s[0] = $c[0]."x".$c[1]."@".$lines[0]->{Light};
#    shift @lines;
    foreach(@lines) {
	@c = $_->get_coords();
#	debug 0, join ",",@c;
	&$scale(\@c);
	$_->{Light} = 0 unless defined $_->{Light};
	push @s,$c[2]."x".$c[3]."@".$_->{Light};

#	debug 0, join ",",@s;
    }
#    debug 0,  'Vector ' . (scalar(@lines)+1) . " " . join(" ",@s);
    return 'Vector ' . (scalar(@lines)+1) . " " . join(" ",@s);
#    print @lines+1," ",join " ",@s,"\n";


} # end coords_to_vector 

} # end  vector context

1;
